# -*- Mode: rpm-spec -*-
#
# (c) Mandriva
#

%define kernelversion	2
%define patchlevel	6
%define sublevel	31

# kernel Makefile extraversion is substituted by
# kpatch/kgit/kstable wich are either 0 (empty), rc (kpatch), git (kgit)
# or stable release (kstable)
%define kpatch		0
%define kstable		5

# kernel.org -gitX patch (only the number after "git")
%define kgit		0

# this is the releaseversion
%define mdvrelease 	1

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-tmb :)
%define ktag		netbook
%define kname 		kernel-%{ktag}

%define rpmtag		%distsuffix
%if %kpatch
%if %kgit
%define rpmrel		%mkrel 0.%{kpatch}.%{kgit}.%{mdvrelease}
%else
%define rpmrel		%mkrel 0.%{kpatch}.%{mdvrelease}
%endif
%else
%define rpmrel		%mkrel %{mdvrelease}
%endif

# theese two never change, they are used to fool rpm/urpmi/smart
%define fakever		1
%define fakerel		%mkrel 1

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%define tar_ver	  	%{kernelversion}.%{patchlevel}.%(expr %{sublevel} - 1)
%else
%if %kstable
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}.%{kstable}
%define tar_ver   	%{kernelversion}.%{patchlevel}.%{sublevel}
%else
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%define tar_ver   	%{kversion}
%endif
%endif
%define kverrel   	%{kversion}-%{rpmrel}

# used for not making too long names for rpms or search paths
%if %kpatch
%if %kgit
%define buildrpmrel     0.%{kpatch}.%{kgit}.%{mdvrelease}%{rpmtag}
%else
%define buildrpmrel     0.%{kpatch}.%{mdvrelease}%{rpmtag}
%endif
%else
%define buildrpmrel     %{mdvrelease}%{rpmtag}
%endif

%define buildrel        %{kversion}-%{buildrpmrel}

# having different top level names for packages means that you have to remove them by hard :(
%define top_dir_name    %{kname}-%{_arch}

%define build_dir       ${RPM_BUILD_DIR}/%{top_dir_name}
%define src_dir         %{build_dir}/linux-%{tar_ver}

# disable useless debug rpms...
%define _enable_debug_packages  %{nil}
%define debug_package           %{nil}

# build defines
%define build_doc 0
%define build_source 1
%define build_devel 1

%define build_kernel 1

%define distro_branch %(perl -pe '/(\\d+)\\.(\\d)\\.?(\\d)?/; $_="$1.$2"' /etc/mandriva-release)

# End of user definitions
%{?_without_kernel: %global build_kernel 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}

%{?_with_kernel: %global build_kernel 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make CC="$CC"
%else
%define kmake %make
%endif
# there are places where parallel make don't work
%define smake make

# Parallelize xargs invocations on smp machines
%define kxargs xargs %([ -z "$RPM_BUILD_NCPUS" ] \\\
	&& RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"; \\\
	[ "$RPM_BUILD_NCPUS" -gt 1 ] && echo "-P $RPM_BUILD_NCPUS")

# Aliases for amd64 builds (better make source links?)
%define target_cpu	%(echo %{_target_cpu} | sed -e "s/amd64/x86_64/")
%define target_arch	%(echo %{_arch} | sed -e "s/amd64/x86_64/")

# src.rpm description
Summary: 	The Linux kernel (the core of the Linux operating system)
Name:           %{kname}
Version:        %{kversion}
Release:        %{rpmrel}
License: 	GPLv2
Group: 		System/Kernel and hardware
ExclusiveArch: 	%{ix86} x86_64
ExclusiveOS: 	Linux
URL:		http://wiki.mandriva.com/en/Docs/Howto/Manbo_Kernels#kernel-netbook

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0:        ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.bz2
Source1:        ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.bz2.sign

# This is for disabling mrproper and other targets on -devel rpms
Source2:	disable-mrproper-in-devel-rpms.patch
# This disables removal of bounds.h and asm-offsets.h in -devel rpms
Source3:	kbuild-really-dont-remove-bounds-asm-offsets-headers.patch

Source4:  	README.kernel-sources
Source5:  	README.MandrivaLinux

# Kernel defconfigs
Source20: 	i386_defconfig
Source21: 	x86_64_defconfig


####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing

%if %kpatch
Patch1:         ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}.bz2
Source10:       ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}.bz2.sign
%endif
%if %kstable
Patch1:         ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kversion}.bz2
Source10:       ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kversion}.bz2.sign
%endif
# kernel.org -git
%if %kgit
Patch2:         ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}-git%{kgit}.bz2
Source11:       ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}-git%{kgit}.bz2.sign
%endif

# patches to be added on stable updates

# Make boot faster
Patch107:	linux-2.6.29-retry-root-mount.patch
Patch108:	linux-2.6.29-dont-wait-for-mouse.patch
Patch109:	linux-2.6.29-enable-async-by-default.patch

Patch120:	gpu-drm-nouveau.patch

Patch130:	kernel-pid-export-find_task_by_vpid-symbol-for-fglrx.patch

Patch142:	platform-x86-dell-laptop-Fix-rfkill-state-setting.patch

# fix the wireless ath9k stability based on fixes merged in 2.6.32-rc1 (#52739)
Patch150:	net-wireless-ath9k-downgrade-ASSERT-in-ath_clone_txbuf.patch
Patch151:	net-wireless-ath9k-Make-sure-we-configure-a-non-zero-beacon-interval.patch
Patch152:	net-wireless-ath9k-differentiate-quality-reporting-between-legacy-and-HT-configurations.patch
Patch153:	net-wireless-ath9k-remove-unnecessary-STATION-mode-check.patch
Patch154:	net-wireless-ath9k-stop-ani-when-the-STA-gets-disconnected.patch
Patch155:	net-wireless-ath9k-race-condition-in-SCANNING-state-check-during-ANI-calibration.patch
Patch156:	net-wireless-ath9k-Handle-different-TX-and-RX-streams-properly.patch
Patch157:	net-wireless-ath9k-downgrade-assert-in-rc.c-for-invalid-rate.patch
Patch158:	net-wireless-ath9k-Manipulate-and-report-the-correct-RSSI.patch
Patch159:	net-wireless-ath9k-RX-stucks-during-heavy-traffic-in-HT40-mode.patch
Patch160:	net-wireless-ath9k-Fix-TX-hang-issue-with-Atheros-chipsets.patch
Patch161:	net-wireless-ath9k-Remove-bogus-assert-in-ath_clone_txbuf.patch
Patch162:	net-wireless-ath9k-Handle-tx-desc-shortage-more-appropriately.patch
Patch163:	net-wireless-ath9k-do-not-stop-the-queues-in-driver-stop.patch
Patch164:	net-wireless-ath9k-Trivial-fix-in-Kconfig.patch
Patch165:	net-wireless-ath9k-Update-beacon-RSSI.patch
Patch166:	net-wireless-ath9k-Fix-bug-in-PCI-resume.patch
Patch167:	net-wireless-ath9k-Set-HW-state-properly.patch
Patch168:	net-wireless-ath9k-Fix-TX-poll-cancelling.patch
Patch169:	net-wireless-ath9k-Fix-bug-in-retrieving-average-beacon-rssi.patch
Patch170:	net-wireless-ath9k-Fix-read-buffer-overflow.patch
Patch171:	net-wireless-ath9k-claim-irq-for-ath9k-not-ath-for-pci.patch
Patch172:	net-wireless-ath9k-Fix-bug-in-ANI-channel-handling.patch
Patch173:	net-wireless-ath9k-Do-a-full-reset-for-AR9280.patch
Patch174:	net-wireless-ath9k-Disable-autosleep-feature-by-default.patch
Patch175:	net-wireless-ath9k-Fix-RFKILL-bugs.patch

# compress modules at make modules_install stage
Patch200:	compress-kernel-modules-on-installation.patch

#END
####################################################################

# Defines for the things that are needed for all the kernels
%define requires1 module-init-tools >= 3.0-7
%define requires2 mkinitrd >= 3.4.43-10
%define requires3 bootloader-utils >= 1.9
%define requires4 sysfsutils module-init-tools >= 0.9.15
%define requires5 kernel-firmware >= 2.6.27-0.rc2.2mdv

%define kprovides kernel = %{tar_ver}, alsa

BuildRoot: 	%{_tmppath}/%{name}-%{kversion}-build-%{_arch}
Autoreqprov: 	no
BuildRequires: 	gcc module-init-tools >= 0.9.15

%description
Source package to build the Linux kernel.

#
# kernel: Symmetric MultiProcessing kernel
#
%if %build_kernel
%package -n %{kname}-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
%ifarch %{ix86}
Summary:	Linux Kernel for netbook use with i586 & 4GB RAM
%else
Summary:	Linux Kernel for netbook use with %{_arch}
%endif
Group:		System/Kernel and hardware
Provides:	%kprovides
Provides:	should-restart = system
Requires:	%requires1
Requires:	%requires2
Requires:	%requires3
Requires:	%requires4
Requires: 	%requires5

%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-%{buildrel}
%ifarch %{ix86}
This kernel is compiled for netbook use, single or multiple i586
processor(s)/core(s) and less than 4GB RAM, using HZ_1000, voluntary
preempt, CFS cpu scheduler and cfq i/o scheduler.
This kernel relies on in-kernel smp alternatives to switch between
up & smp mode depending on detected hardware. To force the kernel
to boot in single processor mode, use the "nosmp" boot parameter.
%else
This kernel is compiled for netbook use, single or multiple %{_arch}
processor(s)/core(s), using HZ_1000, voluntary preempt, CFS cpu
scheduler and cfq i/o scheduler.
This kernel relies on in-kernel smp alternatives to switch between
up & smp mode depending on detected hardware. To force the kernel
to boot in single processor mode, use the "nosmp" boot parameter.
%endif

For instructions for update, see:
http://www.mandriva.com/en/security/kernelupdate
%endif # build_kernel


#
# kernel-source: kernel sources
#
%if %build_source
%package -n %{kname}-source-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
Provides:	%{kname}-source, kernel-source = %{kverrel}, kernel-devel = %{kverrel}
Provides:	%{kname}-source-%{kernelversion}.%{patchlevel}
Requires:	glibc-devel, ncurses-devel, make, gcc, perl
Summary:	The source code for the Linux kernel
Group:		Development/Kernel
Autoreqprov: 	no
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-source-%{buildrel}
The %{kname}-source package contains the source code files for the
Linux kernel. These source files are only needed if you want to build
your own custom kernel that is better tuned to your particular hardware.

If you only want the files needed to build 3rdparty (nVidia, Ati, dkms-*,...)
drivers against, install the *-devel-* rpm that is matching your kernel.

For instructions for update, see:
http://www.mandriva.com/en/security/kernelupdate
%endif #build_source


#
# kernel-devel: stripped kernel sources
#
%if %build_devel
%package -n %{kname}-devel-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
Provides:	kernel-devel = %{kverrel}
Summary:	The %{kname} devel files for 3rdparty modules build
Group:		Development/Kernel
Autoreqprov:	no
Requires:	glibc-devel, ncurses-devel, make, gcc, perl
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-devel-%{buildrel}
This package contains the kernel-devel files that should be enough to build
3rdparty drivers against for use with the %{kname}-%{buildrel}.

If you want to build your own kernel, you need to install the full
%{kname}-source-%{buildrel} rpm.
%endif #build_devel


#
# kernel-doc: documentation for the Linux kernel
#
%if %build_doc
%package -n %{kname}-doc
Version:        %{kversion}
Release:        %{rpmrel}
Summary:	Various documentation bits found in the kernel source
Group:		Books/Computer books
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

For instructions for update, see:
http://www.mandriva.com/en/security/kernelupdate
%endif #build_doc


#
# kernel-latest: virtual rpm
#
%if %build_kernel
%package -n %{kname}-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-%{buildrel}
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname} installed...
%endif #build_kernel


#
# kernel-source-latest: virtual rpm
#
%if %build_source
%package -n %{kname}-source-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-source-%{buildrel}
%ifarch %{ix86}	
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...
%endif #build_source


#
# kernel-devel-latest: virtual rpm
#
%if %build_devel
%package -n %{kname}-devel-latest
Version:        %{kversion}
Release:        %{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-devel
Group: 	  	System/Kernel and hardware
Requires: 	%{kname}-devel-%{buildrel}
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-devel-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-devel installed...
%endif #build_devel


#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

cd %{src_dir}

%if %kpatch
%patch1 -p1
%endif
%if %kstable
%patch1 -p1
%endif
%if %kgit
%patch2 -p1
%endif

# extra patches

%patch107 -p1
%patch108 -p1
%patch109 -p1

# nouveau
%patch120 -p1

# fix fglrx build
%patch130 -p1

# rfkill fixes
%patch142 -p1

# ath9k stability fixes
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch165 -p1
%patch166 -p1
%patch167 -p1
%patch168 -p1
%patch169 -p1
%patch170 -p1
%patch171 -p1
%patch172 -p1
%patch173 -p1
%patch174 -p1
%patch175 -p1

# compress modules at make modules_install stage
%patch200 -p1

# PATCH END

#
# Setup Begin
#


# Install defconfigs...
install %{SOURCE20} %{build_dir}/linux-%{tar_ver}/arch/x86/configs/
install %{SOURCE21} %{build_dir}/linux-%{tar_ver}/arch/x86/configs/

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile


%build
# Common target directories
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _kerneldir /usr/src/linux-%{kversion}-%{ktag}-%{buildrpmrel}
%define _develdir /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel}


# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}
%define temp_source %{temp_root}%{_kerneldir}
%define temp_devel %{temp_root}%{_develdir}


# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}


# make sure we are in the directory
cd %{src_dir}

# make sure EXTRAVERSION says what we want it to say
%if %kstable
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{kstable}-%{ktag}-%{buildrpmrel}/" Makefile
%else
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{ktag}-%{buildrpmrel}/" Makefile
%endif

# Prepare the kernel
%smake -s mrproper
%ifarch %{ix86} x86_64
	cp arch/x86/configs/%{target_arch}_defconfig .config
%else
	cp arch/%{target_arch}/defconfig .config
%endif
%smake oldconfig

# Build the kernel
%kmake all

# Install kernel
install -d %{temp_boot}
install -m 644 System.map \
               %{temp_boot}/System.map-%{kversion}-%{ktag}-%{buildrpmrel}
install -m 644 .config %{temp_boot}/config-%{kversion}-%{ktag}-%{buildrpmrel}
cp -f arch/%{target_arch}/boot/bzImage \
      %{temp_boot}/vmlinuz-%{kversion}-%{ktag}-%{buildrpmrel}

# Install modules
install -d %{temp_modules}/%{kversion}-%{ktag}-%{buildrpmrel}
%smake INSTALL_MOD_PATH=%{temp_root} \
       KERNELRELEASE=%{kversion}-%{ktag}-%{buildrpmrel} \
       modules_install

# remove /lib/firmware, we use a separate kernel-firmware
rm -rf %{temp_root}/lib/firmware

# Save devel tree
%if %build_devel
mkdir -p %{temp_devel}
for i in $(find . -name 'Makefile*'); do cp -R --parents $i %{temp_devel};done
for i in $(find . -name 'Kconfig*' -o -name 'Kbuild*'); do cp -R --parents $i %{temp_devel};done
cp -fR include %{temp_devel}
cp -fR scripts %{temp_devel}
%ifarch %{ix86} x86_64
	cp -fR arch/x86/kernel/asm-offsets.{c,s} %{temp_devel}/arch/x86/kernel/
	cp -fR arch/x86/kernel/asm-offsets_{32,64}.c %{temp_devel}/arch/x86/kernel/
	cp -fR arch/x86/include %{temp_devel}/arch/x86/
%else
	cp -fR arch/%{target_arch}/kernel/asm-offsets.{c,s} %{temp_devel}/arch/%{target_arch}/kernel/
	cp -fR arch/%{target_arch}/include %{temp_devel}/arch/%{target_arch}/
%endif

# Needed for generation of kernel/bounds.s
cp -fR kernel/bounds.c %{temp_devel}/kernel/

# Needed for lguest
cp -fR drivers/lguest/lg.h %{temp_devel}/drivers/lguest/

cp -fR .config Module.symvers %{temp_devel}

# Needed for truecrypt build (Danny)
cp -fR drivers/md/dm.h %{temp_devel}/drivers/md/

# Needed for external dvb tree (#41418)
cp -fR drivers/media/dvb/dvb-core/*.h %{temp_devel}/drivers/media/dvb/dvb-core/
cp -fR drivers/media/dvb/frontends/lgdt330x.h %{temp_devel}/drivers/media/dvb/frontends/

# add acpica header files, needed for fglrx build
cp -fR drivers/acpi/acpica/*.h %{temp_devel}/drivers/acpi/acpica/

# Disable bounds.h and asm-offsets.h removal
patch -p1 -d %{temp_devel} -i %{SOURCE3}

# Check and clean the -devel tree
pushd %{temp_devel} >/dev/null
    %smake -s prepare scripts clean
    rm -f .config.old
popd >/dev/null

# Disable mrproper and other targets
patch -p1 -d %{temp_devel} -i %{SOURCE2}

# Fix permissions
chmod -R a+rX %{temp_devel}
%endif # build_devel

#make sure we are in the directory
cd %src_dir

# kernel-source is shipped as an unprepared tree
%smake -s mrproper


###
### Install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .

cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}
%define target_devel %{buildroot}%{_develdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source}

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in alpha arm avr32 blackfin cris frv h8300 ia64 mips m32r m68k m68knommu \
	 microblaze mn10300 parisc powerpc ppc sh sh64 s390 sparc v850 xtensa; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i

%if %build_devel
	rm -rf %{target_devel}/arch/$i
	rm -rf %{target_devel}/include/asm-$i
%endif
done

# remove arch files based on target arch
%ifnarch %{ix86} x86_64
	rm -rf %{target_source}/arch/x86
	rm -rf %{target_source}/include/asm-x86
%if %build_devel
	rm -rf %{target_devel}/arch/x86
	rm -rf %{target_devel}/include/asm-x86
%endif
%endif

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.tmp_gas_check,.mailmap,.missing-syscalls.d,arch/.gitignore}

#endif %build_source
%endif


# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be

for i in %{target_modules}/*; do
  rm -f $i/build $i/source
done


# Create modules.description
pushd %{target_modules}
for i in *; do
	pushd $i
	echo "Creating modules.description for $i"
	modules=`find . -name "*.ko.gz"`
	echo $modules | %kxargs /sbin/modinfo-25 \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd


###
### Clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be
# able to do several rpm --short-circuit -bi for testing install
# phase without repeating compilation phase
#rm -rf %{temp_root}


###
### Scripts
###

### kernel
%if %build_kernel
%preun -n %{kname}-%{buildrel}
/sbin/installkernel -R %{kversion}-%{ktag}-%{buildrpmrel}
if [ -L /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build ]; then
    rm -f /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source ]; then
    rm -f /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source
fi
pushd /boot > /dev/null
if [ -L vmlinuz-%{ktag} ]; then
    if [ "$(readlink vmlinuz-%{ktag})" = "vmlinuz-%{kversion}-%{ktag}-%{buildrpmrel}" ]; then
	rm -f vmlinuz-%{ktag}
    fi
fi
if [ -L initrd-%{ktag}.img ]; then
    if [ "$(readlink initrd-%{ktag}.img)" = "initrd-%{kversion}-%{ktag}-%{buildrpmrel}.img" ]; then
	rm -f initrd-%{ktag}.img
    fi
fi
popd > /dev/null
exit 0

%post -n %{kname}-%{buildrel}
/sbin/installkernel -L %{kversion}-%{ktag}-%{buildrpmrel}
if [ -d /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel} ]; then
    ln -sf /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel} \
           /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build
    ln -sf /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel} \
           /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source
fi
pushd /boot > /dev/null
if [ -L vmlinuz-%{ktag} ]; then
    rm -f vmlinuz-%{ktag}
fi
ln -sf vmlinuz-%{kversion}-%{ktag}-%{buildrpmrel} vmlinuz-%{ktag}
if [ -L initrd-%{ktag}.img ]; then
    rm -f initrd-%{ktag}.img
fi
ln -sf initrd-%{kversion}-%{ktag}-%{buildrpmrel}.img initrd-%{ktag}.img
popd > /dev/null

%postun -n %{kname}-%{buildrel}
/sbin/kernel_remove_initrd %{buildrel}
%endif # build_kernel


### kernel-devel
%if %build_devel
%post -n %{kname}-devel-%{buildrel}
# place /build and /source symlinks in place.
if [ -d /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel} ]; then
    ln -sf /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel} \
           /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build
    ln -sf /usr/src/linux-%{kversion}-%{ktag}-devel-%{buildrpmrel} \
           /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source
fi

%preun -n %{kname}-devel-%{buildrel}
# we need to delete <modules>/{build,source} at uninstall
if [ -L /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build ]; then
    rm -f /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source ]; then
    rm -f /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/source
fi
exit 0
%endif #build_devel


### kernel-source
%if %build_source
%post -n %{kname}-source-%{buildrel}
if [ -d "/lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}" ]; then
	if [ ! -L $i/build -a ! -L $i/source ]; then
		rm -f $i/{build,source}
	        ln -sf /usr/src/linux-%{kversion}-%{ktag}-%{buildrpmrel} \
	               $i/build
	        ln -sf /usr/src/linux-%{kversion}-%{ktag}-%{buildrpmrel} \
	               $i/source
	fi
fi

%preun -n %{kname}-source-%{buildrel}
for i in /lib/modules/%{kversion}-%{ktag}-%{buildrpmrel}/{build,source}; do
	if [ -L $i ]; then
		if [ "$(readlink $i)" = "/usr/src/linux-%{kversion}-%{ktag}-%{buildrpmrel}" ]; then
			rm -f $i
		fi
	fi
done
exit 0
%endif # build_source


###
### file lists
###

# kernel
%if %build_kernel
%files -n %{kname}-%{buildrel}
%defattr(-,root,root)
%{_bootdir}/config-%{kversion}-%{ktag}-%{buildrpmrel}
%{_bootdir}/vmlinuz-%{kversion}-%{ktag}-%{buildrpmrel}
%{_bootdir}/System.map-%{kversion}-%{ktag}-%{buildrpmrel}
%dir %{_modulesdir}/%{kversion}-%{ktag}-%{buildrpmrel}/
%{_modulesdir}/%{kversion}-%{ktag}-%{buildrpmrel}/kernel
%{_modulesdir}/%{kversion}-%{ktag}-%{buildrpmrel}/modules.*
%doc README.kernel-sources
%doc README.MandrivaLinux
%endif # build_kernel

# kernel-source
%if %build_source
%files -n %{kname}-source-%{buildrel}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.gitignore
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/Kbuild
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/Kconfig
%ifarch %{ix86} x86_64
%{_kerneldir}/arch/x86
%endif
%{_kerneldir}/arch/um
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/firmware
%{_kerneldir}/fs
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm-generic
%ifarch %{ix86} x86_64
%{_kerneldir}/include/asm-x86
%endif
%{_kerneldir}/include/crypto
%{_kerneldir}/include/drm
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/trace
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/mtd
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/keys
%{_kerneldir}/include/rdma
%{_kerneldir}/include/xen
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/samples
%{_kerneldir}/scripts
%{_kerneldir}/security
%{_kerneldir}/sound
%{_kerneldir}/tools
%{_kerneldir}/usr
%{_kerneldir}/virt
%doc README.kernel-sources
%doc README.MandrivaLinux
%endif # build_source

# kernel-devel
%if %build_devel
%files -n %{kname}-devel-%{buildrel}
%defattr(-,root,root)
%dir %{_develdir}
%dir %{_develdir}/arch
%dir %{_develdir}/include
%{_develdir}/.config
%{_develdir}/Documentation
%{_develdir}/Kbuild
%{_develdir}/Makefile
%{_develdir}/Module.symvers
%{_develdir}/arch/Kconfig
%ifarch %{ix86} x86_64
%{_develdir}/arch/x86
%endif
%{_develdir}/arch/um
%{_develdir}/block
%{_develdir}/crypto
%{_develdir}/drivers
%{_develdir}/firmware
%{_develdir}/fs
%{_develdir}/include/Kbuild
%{_develdir}/include/acpi
%{_develdir}/include/asm
%{_develdir}/include/asm-generic
%ifarch %{ix86} x86_64
%{_develdir}/include/asm-x86
%endif
%{_develdir}/include/config
%{_develdir}/include/crypto
%{_develdir}/include/drm
%{_develdir}/include/keys
%{_develdir}/include/linux
%{_develdir}/include/math-emu
%{_develdir}/include/mtd
%{_develdir}/include/net
%{_develdir}/include/pcmcia
%{_develdir}/include/rdma
%{_develdir}/include/scsi
%{_develdir}/include/sound
%{_develdir}/include/trace
%{_develdir}/include/video
%{_develdir}/include/media
%{_develdir}/include/rxrpc
%{_develdir}/include/xen
%{_develdir}/init
%{_develdir}/ipc
%{_develdir}/kernel
%{_develdir}/lib
%{_develdir}/mm
%{_develdir}/net
%{_develdir}/samples
%{_develdir}/scripts
%{_develdir}/security
%{_develdir}/sound
%{_develdir}/tools
%{_develdir}/usr
%doc README.kernel-sources
%doc README.MandrivaLinux
%endif # build_devel


%if %build_doc
%files -n %{kname}-doc
%defattr(-,root,root)
%doc linux-%{tar_ver}/Documentation/*
%endif # build_doc

%if %build_kernel
%files -n %{kname}-latest
%defattr(-,root,root)
%endif # build_kernel

%if %build_source
%files -n %{kname}-source-latest
%defattr(-,root,root)
%endif # build_source

%if %build_devel
%files -n %{kname}-devel-latest
%defattr(-,root,root)
%endif # build_devel


%changelog
* Sat Oct 24 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.5-1mdv2010.0
+ Revision: 459146
- update to 2.6.31.5

* Tue Oct 13 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.4-1mdv2010.0
+ Revision: 457155
- update to 2.6.31.4 (CVE-2009-2903)

* Tue Oct 13 2009 Olivier Blin <oblin@mandriva.com> 2.6.31.3-2mdv2010.0
+ Revision: 457150
- enable pcnet32 network driver (for VirtualBox and VMware)

* Thu Oct 08 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.3-1mdv2010.0
+ Revision: 456073
- update to 2.6.31.3 (tty_port bug)

* Tue Oct 06 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.2-1mdv2010.0
+ Revision: 454577
- compress kernel modules on 'make modules_install' instead
  of after (in spec), as it makes the kernel build require less
  disk space, and also benefits people building their own kernels
  from source (#54028)
- fix ath9k patch list
- fix the wireless ath9k stability based on fixes merged in 2.6.32-rc1 (#52739)
- update to 2.6.31.2

* Thu Sep 24 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.1-1mdv2010.0
+ Revision: 448469
- update to 2.6.31.1
- parallelize xargs invocations on smp machines
- spec cleanup

* Mon Sep 14 2009 Olivier Blin <oblin@mandriva.com> 2.6.31-2mdv2010.0
+ Revision: 440087
- enable pata_amd, we have some Geode netbooks around

* Thu Sep 10 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-1mdv2010.0
+ Revision: 436362
- update to 2.6.31 final

* Sun Sep 06 2009 Anssi Hannula <anssi@mandriva.org> 2.6.31-0.rc9.1mdv2010.0
+ Revision: 432078
- enable kernel modesetting by default when using nouveau driver

  + Thomas Backlund <tmb@mandriva.org>
    - update defconfigs
    - drop merged patches:
      fs-inotify-do-not-send-a-block-of-zeros-when-no-pathname-is-available.patch
      fs-inotify-fix-length-reporting-and-size-checking.patch
      fs-inotify-update-the-group-mask-on-mark-addition.patch
    - update to 2.6.31-rc9

* Fri Aug 28 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc8.3mdv2010.0
+ Revision: 422030
- inotify: fix length reporting and size checking
  inotify: update the group mask on mark addition
- fix inotify regression in -rc8 causing boot hang/failure

* Fri Aug 28 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc8.1mdv2010.0
+ Revision: 421906
- enable DRM_I915_KMS
- make AGP builtin
- update to 2.6.31-rc8

* Sat Aug 22 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc7.1mdv2010.0
+ Revision: 419671
- update to 2.6.31-rc7
- drop merged patches:
  dvb-usb-af9015-fix-crash.patch
- disable MAC80211_DEFAULT_PS (powersaving) as it's known to cause instabilities
  and performance regressions on wireless drivers including iwlwifi and p54.

* Fri Aug 14 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc6.1mdv2010.0
+ Revision: 416265
- update to 2.6.31-rc6

* Thu Aug 13 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc5.9.4mdv2010.0
+ Revision: 415939
- update nouveau to 2009-08-12
- drop merged patches
- update to 2.6.31-rc5-git9

* Fri Aug 07 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc5.3.3mdv2010.0
+ Revision: 411359
- fix lockdep bug in net core
- drm: radeon rs880 pci ids, radeon kms TTM patch,
  radeon kms suspend/resume fix.
- update nouveau to 2009-08-07 snapshot
- update to 2.6.31-rc5-git3
- enable TIGON3 (tg3) nic support (#52668)

* Sat Aug 01 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc5.2mdv2010.0
+ Revision: 406696
- fix crash in dvb-usb-af9015
- update nouveau to 20090801 git snapshot
- drop nouveau buildfix
- update to 2.6.31-rc5
  - drop merged patches:
    net-rfkill-fix-rfkill_set_states-to-set-the-hw-state.patch
    platform-x86-acer-wmi-rfkill-reversion.patch
  - add patches:
    fix nouveau build with 2.6.31-rc5
  - update defconfigs

* Mon Jul 27 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc4.2mdv2010.0
+ Revision: 400995
- fix dell-laptop rfkill state change logic
- fix reversed rfkill on acer-wmi
- fix rfkill_set_states to set the hw state
- add static symlinks in /boot

* Sun Jul 26 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31-0.rc4.1mdv2010.0
+ Revision: 400263
- add /tools to filelists
- remove microblaze arch
- update defconfigs
- re-export find_task_by_vpid symbol again, needed for Ati fglrx
- add nouveau support
- rediff patches 107-109 to apply cleanly
- drop patches 110, 111: merged upstream
- fix source2 and source3 tu apply cleanly
- drop unused broken patches 101-105: poulsbo support
- drop merged patches 106 (atom coretemp),112 (via card reader)
- drop patches 113-125: stable fixes merged upstream
- update to 2.6.31-rc4

* Mon Jul 20 2009 Thomas Backlund <tmb@mandriva.org> 2.6.29.6-4mdv2010.0
+ Revision: 398102
- add patches from 2.6.30.2 -stable
    * personality: fix PER_CLEAR_ON_SETID (CVE-2009-1895)
    * Makefile: add fno-delete-null-pointer-checks to gcc cflags
    * block: restore barrier support for md and probably other
      virtual devices
    * iommu: fix address space allocation
    * floppy: fix lock imbalance
    * fuse: fix bad return value in fuse_file_poll
    * fuse: fix return value of fuse_dev_write
    * futexes: fix infinite loop in get_futex_key-on-huge-page
    * kernel-resource.c: fix sign extension in reserve_setup
    * md: avoid dereferencing null pointer when accessing
      suspend_ sysfs attributes
    * md: fix error path when duplicate name is found on md
      device creation.
    * md: raid5 suspend shouldnt affect read requests
    * security: use mmap_min_addr indepedently of security models

* Wed Jul 15 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.6-3mdv2010.0
+ Revision: 396404
- Add via card reader support (sd/mmc only) v5 patch from Joseph Chan.

* Sat Jul 04 2009 Thomas Backlund <tmb@mandriva.org> 2.6.29.6-1mdv2010.0
+ Revision: 391959
- update to 2.6.29.6

* Fri Jun 26 2009 Thomas Backlund <tmb@mandriva.org> 2.6.29.5-1mdv2010.0
+ Revision: 389288
- update to 2.6.29.5 (CVE-2009-1630, CVE-2009-1385)
- enable in defconfigs:
  * TASKSTATS, TASK_DELAY_ACCT, TASK_XACCT, TASK_IO_ACCOUNTING (#51743)
- enable in defconfig-x86_64:
  * AUDIT, AUDITSYSCALL, AUDIT_TREE (like i386)
- rediff patches to apply cleanly:
  * linux-2.6.29-enable-async-by-default.patch
  * linux-2.6.29-retry-root-mount.patch

  + Paulo Ricardo Zanoni <pzanoni@mandriva.com>
    - Integrate the kernel-instanton's patches to kernel-netbook (faster boot)

  + Olivier Blin <oblin@mandriva.com>
    - enable CONFIG_AUDITSYSCALL (for readahead-collector)

* Wed May 20 2009 Thomas Backlund <tmb@mandriva.org> 2.6.29.4-1mdv2010.0
+ Revision: 378083
- update to 2.6.29.4

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Summary and description fixes.

* Mon Apr 27 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.2-1mdv2009.1
+ Revision: 369090
- Updated to 2.6.29.2
- Make ext2/ext4 builtin.
- Disabled CONFIG_IDE
- Set CONFIG_NR_CPUS=4
- Atom support in coretemp (from main kernel,
  http://bugzilla.kernel.org/show_bug.cgi?id=11161).
- Don't enable i915 modesetting by default yet.
- Disabled poulsbo dri patches as they break drm (eg. i915 dri stops to
  work properly).
- Make ahci and sd_mod builtin.
- Make installed files with correct netbook tag.
- Updated URL for added wiki entry about kernel-netbook.

* Tue Apr 21 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.1-1mdv2009.1
+ Revision: 368588
- Updated to 2.6.29.1
  * removed net-gro-disable-gro-onlegacy-netif_rx-path.patch (merged)
- Added poulsbo drm patches.
- Import initial spec and config files.
- Created package structure for kernel-netbook.

